@@ -12,11 +12,10 @@ from .web_page import WebPage
 from .configs.chromium_options import ChromiumOptions
 from .configs.session_options import SessionOptions
 
-# 常用工具
-from .action_chains import ActionChains
-from .keys import Keys
-
 # 旧版页面类和启动配置类
-from .mix_page import MixPage
-from .drission import Drission
-from .configs.driver_options import DriverOptions
+try:
+    from .mixpage.mix_page import MixPage
+    from .mixpage.drission import Drission
+    from .configs.driver_options import DriverOptions
+except ModuleNotFoundError:
+    pass
