@@ -71,7 +71,7 @@ class BaseElement(BaseParser):
         pass
 
     def _ele(self, loc_or_str, timeout=None, single=True, relative=False, raise_err=None):
-        r = self._find_elements(loc_or_str,  timeout=timeout, single=single, relative=relative, raise_err=raise_err)
+        r = self._find_elements(loc_or_str, timeout=timeout, single=single, relative=relative, raise_err=raise_err)
         if not single or raise_err is False:
             return r
         if not r and (Settings.raise_ele_not_found or raise_err is True):
@@ -140,14 +140,38 @@ class DrissionElement(BaseElement):
 
         return self._ele(loc, timeout=0, relative=True, raise_err=False)
 
-    def prev(self, index=1, filter_loc='', timeout=0):
+    def child(self, index=1, filter_loc='', timeout=None, ele_only=True):
+        """返回直接子元素元素或节点组成的列表，可用查询语法筛选
+        :param index: 第几个查询结果，1开始
+        :param filter_loc: 用于筛选的查询语法
+        :param timeout: 查找节点的超时时间
+        :param ele_only: 是否只获取元素，为False时把文本、注释节点也纳入
+        :return: 直接子元素或节点文本组成的列表
+        """
+        nodes = self.children(filter_loc=filter_loc, timeout=timeout, ele_only=ele_only)
+        if not nodes:
+            if Settings.raise_ele_not_found:
+                raise ElementNotFoundError
+            else:
+                return NoneElement()
+
+        try:
+            return nodes[index - 1]
+        except IndexError:
+            if Settings.raise_ele_not_found:
+                raise ElementNotFoundError
+            else:
+                return NoneElement()
+
+    def prev(self, index=1, filter_loc='', timeout=0, ele_only=True):
         """返回前面的一个兄弟元素，可用查询语法筛选，可指定返回筛选结果的第几个
-        :param index: 前面第几个查询结果元素
-        :param filter_loc: 用于筛选元素的查询语法
-        :param timeout: 查找元素的超时时间
+        :param index: 前面第几个查询结果，1开始
+        :param filter_loc: 用于筛选的查询语法
+        :param timeout: 查找节点的超时时间
+        :param ele_only: 是否只获取元素，为False时把文本、注释节点也纳入
         :return: 兄弟元素
         """
-        nodes = self._get_brothers(index, filter_loc, 'preceding', timeout=timeout)
+        nodes = self._get_brothers(index, filter_loc, 'preceding', timeout=timeout, ele_only=ele_only)
         if nodes:
             return nodes[-1]
         if Settings.raise_ele_not_found:
@@ -155,14 +179,15 @@ class DrissionElement(BaseElement):
         else:
             return NoneElement()
 
-    def next(self, index=1, filter_loc='', timeout=0):
+    def next(self, index=1, filter_loc='', timeout=0, ele_only=True):
         """返回后面的一个兄弟元素，可用查询语法筛选，可指定返回筛选结果的第几个
-        :param index: 后面第几个查询结果元素
-        :param filter_loc: 用于筛选元素的查询语法
-        :param timeout: 查找元素的超时时间
+        :param index: 后面第几个查询结果，1开始
+        :param filter_loc: 用于筛选的查询语法
+        :param timeout: 查找节点的超时时间
+        :param ele_only: 是否只获取元素，为False时把文本、注释节点也纳入
         :return: 兄弟元素
         """
-        nodes = self._get_brothers(index, filter_loc, 'following', timeout=timeout)
+        nodes = self._get_brothers(index, filter_loc, 'following', timeout=timeout, ele_only=ele_only)
         if nodes:
             return nodes[0]
         if Settings.raise_ele_not_found:
@@ -170,14 +195,15 @@ class DrissionElement(BaseElement):
         else:
             return NoneElement()
 
-    def before(self, index=1, filter_loc='', timeout=None):
+    def before(self, index=1, filter_loc='', timeout=None, ele_only=True):
         """返回前面的一个兄弟元素，可用查询语法筛选，可指定返回筛选结果的第几个
-        :param index: 前面第几个查询结果元素
-        :param filter_loc: 用于筛选元素的查询语法
-        :param timeout: 查找元素的超时时间
+        :param index: 前面第几个查询结果，1开始
+        :param filter_loc: 用于筛选的查询语法
+        :param timeout: 查找节点的超时时间
+        :param ele_only: 是否只获取元素，为False时把文本、注释节点也纳入
         :return: 本元素前面的某个元素或节点
         """
-        nodes = self._get_brothers(index, filter_loc, 'preceding', False, timeout=timeout)
+        nodes = self._get_brothers(index, filter_loc, 'preceding', False, timeout=timeout, ele_only=ele_only)
         if nodes:
             return nodes[-1]
         if Settings.raise_ele_not_found:
@@ -185,14 +211,15 @@ class DrissionElement(BaseElement):
         else:
             return NoneElement()
 
-    def after(self, index=1, filter_loc='', timeout=None):
+    def after(self, index=1, filter_loc='', timeout=None, ele_only=True):
         """返回后面的一个兄弟元素，可用查询语法筛选，可指定返回筛选结果的第几个
-        :param index: 后面第几个查询结果元素
-        :param filter_loc: 用于筛选元素的查询语法
-        :param timeout: 查找元素的超时时间
+        :param index: 后面第几个查询结果，1开始
+        :param filter_loc: 用于筛选的查询语法
+        :param timeout: 查找节点的超时时间
+        :param ele_only: 是否只获取元素，为False时把文本、注释节点也纳入
         :return: 本元素后面的某个元素或节点
         """
-        nodes = self._get_brothers(index, filter_loc, 'following', False, timeout)
+        nodes = self._get_brothers(index, filter_loc, 'following', False, timeout, ele_only=ele_only)
         if nodes:
             return nodes[0]
         if Settings.raise_ele_not_found:
@@ -200,42 +227,68 @@ class DrissionElement(BaseElement):
         else:
             return NoneElement()
 
-    def prevs(self, filter_loc='', timeout=0):
+    def children(self, filter_loc='', timeout=None, ele_only=True):
+        """返回直接子元素元素或节点组成的列表，可用查询语法筛选
+        :param filter_loc: 用于筛选的查询语法
+        :param timeout: 查找节点的超时时间
+        :param ele_only: 是否只获取元素，为False时把文本、注释节点也纳入
+        :return: 直接子元素或节点文本组成的列表
+        """
+        if not filter_loc:
+            loc = '*' if ele_only else 'node()'
+        else:
+            loc = get_loc(filter_loc, True)  # 把定位符转换为xpath
+            if loc[0] == 'css selector':
+                raise ValueError('此css selector语法不受支持，请换成xpath。')
+            loc = loc[1].lstrip('./')
+
+        loc = f'xpath:./{loc}'
+        nodes = self._ele(loc, timeout=timeout, single=False, relative=True)
+        return [e for e in nodes if not (isinstance(e, str) and sub('[ \n\t\r]', '', e) == '')]
+
+    def prevs(self, filter_loc='', timeout=0, ele_only=True):
         """返回前面全部兄弟元素或节点组成的列表，可用查询语法筛选
-        :param filter_loc: 用于筛选元素的查询语法
-        :param timeout: 查找元素的超时时间
+        :param filter_loc: 用于筛选的查询语法
+        :param timeout: 查找节点的超时时间
+        :param ele_only: 是否只获取元素，为False时把文本、注释节点也纳入
         :return: 兄弟元素或节点文本组成的列表
         """
-        return self._get_brothers(filter_loc=filter_loc, direction='preceding', timeout=timeout)
+        return self._get_brothers(filter_loc=filter_loc, direction='preceding', timeout=timeout, ele_only=ele_only)
 
-    def nexts(self, filter_loc='', timeout=0):
+    def nexts(self, filter_loc='', timeout=0, ele_only=True):
         """返回后面全部兄弟元素或节点组成的列表，可用查询语法筛选
-        :param filter_loc: 用于筛选元素的查询语法
-        :param timeout: 查找元素的超时时间
+        :param filter_loc: 用于筛选的查询语法
+        :param timeout: 查找节点的超时时间
+        :param ele_only: 是否只获取元素，为False时把文本、注释节点也纳入
         :return: 兄弟元素或节点文本组成的列表
         """
-        return self._get_brothers(filter_loc=filter_loc, direction='following', timeout=timeout)
+        return self._get_brothers(filter_loc=filter_loc, direction='following', timeout=timeout, ele_only=ele_only)
 
-    def befores(self, filter_loc='', timeout=None):
+    def befores(self, filter_loc='', timeout=None, ele_only=True):
         """返回后面全部兄弟元素或节点组成的列表，可用查询语法筛选
-        :param filter_loc: 用于筛选元素的查询语法
-        :param timeout: 查找元素的超时时间
+        :param filter_loc: 用于筛选的查询语法
+        :param timeout: 查找节点的超时时间
+        :param ele_only: 是否只获取元素，为False时把文本、注释节点也纳入
         :return: 本元素前面的元素或节点组成的列表
         """
-        return self._get_brothers(filter_loc=filter_loc, direction='preceding', brother=False, timeout=timeout)
+        return self._get_brothers(filter_loc=filter_loc, direction='preceding',
+                                  brother=False, timeout=timeout, ele_only=ele_only)
 
-    def afters(self, filter_loc='', timeout=None):
+    def afters(self, filter_loc='', timeout=None, ele_only=True):
         """返回前面全部兄弟元素或节点组成的列表，可用查询语法筛选
-        :param filter_loc: 用于筛选元素的查询语法
-        :param timeout: 查找元素的超时时间
+        :param filter_loc: 用于筛选的查询语法
+        :param timeout: 查找节点的超时时间
+        :param ele_only: 是否只获取元素，为False时把文本、注释节点也纳入
         :return: 本元素后面的元素或节点组成的列表
         """
-        return self._get_brothers(filter_loc=filter_loc, direction='following', brother=False, timeout=timeout)
+        return self._get_brothers(filter_loc=filter_loc, direction='following',
+                                  brother=False, timeout=timeout, ele_only=ele_only)
 
-    def _get_brothers(self, index=None, filter_loc='', direction='following', brother=True, timeout=.5):
+    def _get_brothers(self, index=None, filter_loc='', direction='following',
+                      brother=True, timeout=.5, ele_only=True):
         """按要求返回兄弟元素或节点组成的列表
         :param index: 获取第几个，该参数不为None时只获取该编号的元素
-        :param filter_loc: 用于筛选元素的查询语法
+        :param filter_loc: 用于筛选的查询语法
         :param direction: 'following' 或 'preceding'，查找的方向
         :param brother: 查找范围，在同级查找还是整个dom前后查找
         :param timeout: 查找等待时间
@@ -247,7 +300,7 @@ class DrissionElement(BaseElement):
         brother = '-sibling' if brother else ''
 
         if not filter_loc:
-            loc = '*'
+            loc = '*' if ele_only else 'node()'
 
         else:
             loc = get_loc(filter_loc, True)  # 把定位符转换为xpath
@@ -349,7 +402,7 @@ class BasePage(BaseParser):
         return
 
     @abstractmethod
-    def get_cookies(self, as_dict=False):
+    def get_cookies(self, as_dict=False, all_info=False):
         return {}
 
     @abstractmethod
@@ -359,7 +412,9 @@ class BasePage(BaseParser):
     def _ele(self, loc_or_ele, timeout=None, single=True, raise_err=None):
         if not loc_or_ele:
             raise ElementNotFoundError
-        r = self._find_elements(loc_or_ele,  timeout=timeout, single=single, raise_err=raise_err)
+
+        r = self._find_elements(loc_or_ele, timeout=timeout, single=single, raise_err=raise_err)
+
         if not single or raise_err is False:
             return r
         if not r and (Settings().raise_ele_not_found is True or raise_err is True):
