@@ -81,6 +81,11 @@ class SessionPage(BasePage):
         """返回当前访问url"""
         return self._url
 
+    @property
+    def _session_url(self):
+        """返回当前访问url"""
+        return self._url
+
     @property
     def html(self):
         """返回页面的html文本"""
@@ -180,26 +185,34 @@ class SessionPage(BasePage):
         """
         return loc_or_ele if isinstance(loc_or_ele, SessionElement) else make_session_ele(self, loc_or_ele, single)
 
-    def get_cookies(self, as_dict=False, all_domains=False):
+    def get_cookies(self, as_dict=False, all_domains=False, all_info=False):
         """返回cookies
-        :param as_dict: 是否以字典方式返回
+        :param as_dict: 是否以字典方式返回，False则以list返回
         :param all_domains: 是否返回所有域的cookies
+        :param all_info: 是否返回所有信息，False则只返回name、value、domain
         :return: cookies信息
         """
         if all_domains:
             cookies = self.session.cookies
         else:
             if self.url:
-                url = extract(self.url)
-                domain = f'{url.domain}.{url.suffix}'
+                ex_url = extract(self._session_url)
+                domain = f'{ex_url.domain}.{ex_url.suffix}' if ex_url.suffix else ex_url.domain
+
                 cookies = tuple(x for x in self.session.cookies if domain in x.domain or x.domain == '')
             else:
                 cookies = tuple(x for x in self.session.cookies)
 
         if as_dict:
             return {x.name: x.value for x in cookies}
-        else:
+        elif all_info:
             return [cookie_to_dict(cookie) for cookie in cookies]
+        else:
+            r = []
+            for c in cookies:
+                c = cookie_to_dict(c)
+                r.append({'name': c['name'], 'value': c['value'], 'domain': c['domain']})
+            return r
 
     def post(self, url, data=None, show_errmsg=False, retry=None, interval=None, **kwargs):
         """用post方式跳转到url
@@ -268,9 +281,6 @@ class SessionPage(BasePage):
         if not check_headers(kwargs, self.session.headers, 'timeout'):
             kwargs['timeout'] = self.timeout
 
-        if 'allow_redirects' not in kwargs:
-            kwargs['allow_redirects'] = False
-
         r = err = None
         retry = retry if retry is not None else self.retry_times
         interval = interval if interval is not None else self.retry_interval
@@ -335,6 +345,14 @@ class SessionPageSetter(object):
     def __init__(self, page):
         self._page = page
 
+    def retry_times(self, times):
+        """设置连接失败时重连次数"""
+        self._page.retry_times = times
+
+    def retry_interval(self, interval):
+        """设置连接失败时重连间隔"""
+        self._page.retry_interval = interval
+
     def timeout(self, second):
         """设置连接超时时间
         :param second: 秒数
